import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk._jsii
import cdk8s._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@opencdk8s/cdk8s-external-dns-route53",
    "0.1.0",
    __name__[0:-6],
    "cdk8s-external-dns-route53@0.1.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
